@@ -15,7 +15,7 @@ use Types::Standard qw/ is_Int Int ArrayRef /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.2.0';
 
 
 has total_entries => (
@@ -258,6 +258,26 @@ sub pages_in_set {
 }
 
 
+sub previous_set {
+    my ($self) = @_;
+
+    my $page = $self->current_page - (2 * $self->pages_per_exponent) - 1;
+    return $page < $self->first_page
+        ? undef
+        : $page;
+}
+
+
+sub next_set {
+    my ($self) = @_;
+
+    my $page = $self->current_page + (2 * $self->pages_per_exponent) - 1;
+    return $page > $self->last_page
+        ? undef
+        : $page;
+}
+
+
 sub change_entries_per_page {
     my ($self, $value) = @_;
 
@@ -307,7 +327,7 @@ Data::Pageset::Exponential - Page numbering for very large page numbers
 
 =head1 VERSION
 
-version v0.1.0
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -420,6 +440,20 @@ Returns the number of the next page.
 
 Returns an array reference of pages in the page set.
 
+=head2 C<previous_set>
+
+This returns the first page number of the previous page set, for the
+first exponent.
+
+It is added for compatability with L<Data::Pageset>.
+
+=head2 C<next_set>
+
+This returns the first page number of the next page set, for the first
+exponent.
+
+It is added for compatability with L<Data::Pageset>.
+
 =for Pod::Coverage change_entries_per_page
 
 =for Pod::Coverage BUILDARGS
@@ -448,10 +482,26 @@ L<Data::Pageset>
 
 =back
 
+=head1 SOURCE
+
+The development version is on github at L<https://github.com/robrwo/Data-Pageset-Exponential>
+and may be cloned from L<git://github.com/robrwo/Data-Pageset-Exponential.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/robrwo/Data-Pageset-Exponential/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Robert Rothenberg <rrwo@cpan.org>
 
+Test code was adapted from L<Data::Page> to ensure compatability.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018-2019 by Robert Rothenberg.
